import tomllib
from pathlib import Path
from typing import Any, Dict

class ConfigManager:
    def __init__(self, file_path: str):
        self.file_path = Path(file_path)
        self.config: Dict[str, Any] = {}
        self._load()

    def _load(self) -> None:
        if not self.file_path.exists():
            raise FileNotFoundError(f"Config file not found: {self.file_path}")

        with open(self.file_path, "rb") as f:
            self.config = tomllib.load(f)

    def get(self, key: str, default: Any = None) -> Any:
        keys = key.split(".")
        value = self.config

        try:
            for k in keys:
                value = value[k]
            return value
        except (KeyError, TypeError):
            return default

    def __getitem__(self, key: str) -> Any:
        return self.get(key)

    def __contains__(self, key: str) -> bool:
        keys = key.split(".")
        value = self.config

        try:
            for k in keys:
                value = value[k]
            return True
        except (KeyError, TypeError):
            return False
