from typing import Callable, List, Dict, Type, Union
from nio import Event, InviteEvent, MatrixRoom
from core.logger import logger

class EventDispatcher:
    def __init__(self):
        self.subscribers: Dict[type[Union[Event, InviteEvent]], List[Callable]] = {}

    def subscribe(self, event_type: Type[Union[InviteEvent, Event]], handler: Callable):
        if event_type not in self.subscribers:
            self.subscribers[event_type] = []
        self.subscribers[event_type].append(handler)

    def unsubscribe(self, event_type: Type[Union[InviteEvent, Event]], handler: Callable):
        if event_type in self.subscribers:
            self.subscribers[event_type].remove(handler)

    async def dispatch(self, room: MatrixRoom, event: Union[Event, InviteEvent]):
        event_type = type(event)
        if event_type in self.subscribers:
            for handler in self.subscribers[event_type]:
                try:
                    await handler(room, event)
                except Exception as e:
                    logger.error(f"Error occurred while handling event: {e}")
